=======================
Ironic Inspector Policy
=======================

The following is a sample **ironic-inspector** policy file, autogenerated from
Ironic Inspector when this documentation is built.
To avoid issues, make sure your version of **ironic-inspector**
matches that of the example policy file.

The sample policy can also be downloaded as a :download:`file
</_static/ironic-inspector.policy.yaml.sample>`.

.. literalinclude:: /_static/ironic-inspector.policy.yaml.sample
